#
# spec file for package gajim
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _version 0.16
Name:           gajim
Version:        0.16.7
Release:        4.3.1
Summary:        Full-featured XMPP client written in Python and Gtk2
License:        GPL-3.0-only
Group:          Productivity/Networking/Talk/Clients
Url:            https://gajim.org/
Source:         https://gajim.org/downloads/%{_version}/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE gajim-do_not_ship_certificate.patch.in vilene@posteo.net -- Do not package the PEM certificate.
Source1:        gajim-do_not_ship_certificate.patch.in
# PATCH-FIX-UPSTREAM gajim-0.16.7-default-disable-xep-0146.patch bsc#1041163 forenjunkie@chello.at -- Add a config option to activate XEP-0146 commands (commit cb65cfc).
Patch0:         gajim-0.16.7-default-disable-xep-0146.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  p11-kit-devel
BuildRequires:  pkgconfig
BuildRequires:  python-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-2.0)
Requires:       ca-certificates-mozilla
Requires:       dbus-1-python
Requires:       python-gnupg
Requires:       python-gtk >= 2.2
Requires:       python-nbxmpp >= 0.5.3
Requires:       python-pyOpenSSL >= 0.12
Requires:       python-pyasn1
Requires:       python-xml
Recommends:     %{name}-lang
# nslookup for SRV support.
Recommends:     bind-utils
Recommends:     gtkspell
# End-to-end encryption.
Recommends:     python-pycrypto
# zeroconf support.
Suggests:       dbus-1-glib
# KWallet support.
Suggests:       kwalletcli
# Idle module.
Suggests:       libXss1
Suggests:       python-avahi
# Audio/Video Chat
Suggests:       python-farstream-0_1
# GNOME Keyring support.
Suggests:       python-gnomekeyring
BuildArch:      noarch

%description
The goal of Gajim is to provide a full featured and easy to use
Jabber/XMPP client. Gajim works nicely with MATE and GNOME, but does
require neither to run.

Features:
 * Tabbed chat window and single window modes.
 * Group chat support (with Multi-User Chat protocol), invitation,
   chat to group chat transformation, minimise group chat to roster.
 * Emoticons, avatars, PEP (user activity, mood and tune).
 * Audio / video conferences.
 * File transfer, room bookmarks.
 * Metacontacts support.
 * Trayicon, speller, extended chat history functionalities.
 * TLS, GPG and End-To-End encryption support (with SSL legacy support).
 * Transport registration support.
 * Service discovery including nodes, user search.
 * Wikipedia, dictionary and search engine lookup.
 * Multiple accounts support.
 * DBus capabilities. Read more information.
 * XML console.
 * Link local (bonjour / zeroconf), BOSH.
 * Other features via plugins.

%lang_package

%prep
%setup -q
%patch0 -p1
sed -i '/^_Keywords/d' data/%{name}.desktop.in.in

# Do not package the PEM certificate.
sed 's|@TRUSTDIR_STATIC@|%{trustdir_static}|' %{SOURCE1} | patch -F0 -p1 --no-backup-if-mismatch

%build
export PYTHON=python2
autoreconf -fi
%configure \
  --prefix=%{_prefix}    \
  --enable-site-packages
make %{?_smp_mflags} V=1

%install
%make_install
dirname $(find %{buildroot}%{python_sitelib} -name '*.py') | sort -u | while read dir; do
    pushd "$dir"
    # Fix python-bytecode-inconsistent-mtime (hacky).
    rm -f *.pyc *.pyo
    touch -c *.py
    %py_compile .
    popd
done

%suse_update_desktop_file -r %{name} Network InstantMessaging
%fdupes %{buildroot}%{_prefix}/
%find_lang %{name}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%doc AUTHORS ChangeLog COPYING README THANKS*
%{_bindir}/%{name}*
%{_datadir}/%{name}/
%{python_sitelib}/%{name}/
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/icons/hicolor/*/*/*
%{_mandir}/man?/%{name}*%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Tue Jul  4 2017 vilene@posteo.net
- Add gajim-do_not_ship_certificate.patch.in: Do not package
  bundled PEM certificate, use one provided by package
  `ca-certificates-mozilla' instead (boo#1071571).
* Mon May 29 2017 sor.alexei@meowr.ru
- Add gajim-0.16.7-default-disable-xep-0146.patch by
  Philipp Hörist: Add a config option to activate XEP-0146 commands
  (commit cb65cfc, CVE-2016-10376, bsc#1041163).
* Tue May  9 2017 sor.alexei@meowr.ru
- Update to version 0.16.7:
  * Better compatibility with XEP-0191: Blocking Command.
  * Gajim now depends on python-gnupg for PGP encryption.
  * Remove usage of demandimport.
  * Many minor bugfixes.
- Move python-farstream-0_1 to Suggests.
- Correct the licence to GPL-3.0.
* Thu Oct 13 2016 sor.alexei@meowr.ru
- Update to version 0.16.6:
  * Fix using gpg2.
  * Improve message receips usage.
  * Improve roster filtering.
  * Fix several minor bugs.
- Remove gajim-remote-dont-show.patch: merged upstream.
* Tue May 24 2016 mvetter@suse.com
- Add gajim-remote-dont-show.patch:
  gajim-remote is cli only. Dont list it in menus.
- If python-gstreamer-0_10 is installed the error message
  'ImportError: could not import gst' is not shown.
  See: https://trac.gajim.org/ticket/7836
* Tue Dec 29 2015 sor.alexei@meowr.ru
- Update to 0.16.5:
  * Improve MAM implementation.
  * Improve security on connexion and for roster managment
    (rh#1295475, bsc#960668, CVE-2015-8688)
  * Ability for emoticons to be sorted in menu.
* Sun Sep 27 2015 sor.alexei@meowr.ru
- Update to 0.16.4:
  * Fix trusting GPG keys.
  * Ability to disable synchronisation of logs with server.
  * Improve MAM usage.
* Sun Aug  2 2015 sor.alexei@meowr.ru
- Update to 0.16.3:
  * Fix reading secret file.
  * Fix reconnection after suspend.
  * Fix sending GPG-encrypted file to non-trusted key.
* Sat Jul 25 2015 sor.alexei@meowr.ru
- Update to 0.16.2:
  * Improve Zeroconf (Avahi) with IPv6.
  * Fix errors with GnuPG.
  * Minor fixes and improvements.
* Sun Mar  1 2015 sor.alexei@meowr.ru
- Update to 0.16.1:
  * Fix sending Zeroconf messages.
  * Make ipython compatible to version >= 1.0.
  * Support XEP-0313 MAM.
  * Minor fixes and improvements.
* Tue Feb 10 2015 sor.alexei@meowr.ru
- Add python-farstream-0_1 optional dependency.
* Sat Oct 11 2014 sor.alexei@meowr.ru
- Update to 0.16:
  * Improve File transfer support by adding Jingle file transfer.
  * Use external python-nbxmpp library.
  * improve security.
  * Improve audio / Video calls and add screensharing feature.
  * Support audio under windows.
  * Support systemd-logind.
  * Support XEP-0308 Last message correction.
  * Support XEP-0224 Attention.
  * Support XEP-0191 Blocking command.
  * Support XEP-0249 Direct Invitation.
  * Better RTL languages support.
  * Use host command to resolve SRV records if it is available.
- Completely review dependencies.
- Spec cleanup.
- Separate gajim-lang package.
- Purge --enable-{remote ,gtkspell,idle,trayicon} from configure
  options and trust the defaults.
- Replace Python bytecode generation script with a more verbose one.
- Generate icon cache after package installation.
- Enable Python site packages.
* Mon May 27 2013 zaitor@opensuse.org
- Update to version 0.15.4:
  * Fix usage of OTR plugin
  * Fix connection to non-SSL server
  * Fix receiving GPG-encrypted messages while offline.
- Changes from version 0.15.3:
  * Better handling of SSL errors
  * Better handling of canceling file transfer
  * Improve farstream calls
  * Minor fixes and improvements
- Changes from version 0.15.2:
  * Show punycode encoded urls if they contain non-ascii chars
  * Fix crash when pressing Esc in chat window
  * Support Network Manager 0.9
  * decrypt GPG messages in the correct order
- Changes from version 0.15.1:
  * Switch from python-farsight to python-farstream
  * improve performances
  * Fix roster filter with unicode chars
  * Fix connection to msn jabber server
  * Fix some GPG issues
  * Fix other small issues
- Drop gajim-CVE-2012-2093-fix_insecure_temp_file_for_latex.patch,
  fixed upstream.
- Add python-farstream Recommends, fixes bnc#821233.
* Thu May 24 2012 pascal.bleser@opensuse.org
- add gajim-CVE-2012-2093-fix_insecure_temp_file_for_latex.patch
  (CVE#2012-2093) which fixes insecure usage of temporary files for rendering
  LaTeX markup, see also bnc#763452
* Wed May 23 2012 pascal.bleser@opensuse.org
- update to 0.15
* Sat Sep 10 2011 pascal.bleser@opensuse.org
- changed Requires:python-gstreamer to python-gstreamer-0_10, thanks to Peter
  von Arx for reporting
* Sat Sep  3 2011 prusnak@opensuse.org
- updated to 0.14.4
  * Fix translation issue
  * other minor fixes
- updated to 0.14.3
  * Fix history viewer
  * Fix closing roster window
  * Prevent some erros with metacontacts
- updated to 0.14.2
  * Fix CPU usage when testing file transfer proxies
  * Fix invalid XML char regex
  * Fix subscription request window handling
  * Fix URL display in chat message banner
  * Other minor bugfixes
- updated to 0.14.1
  * Fix changing account name
  * Fix sending XHTML
  * Fix GnomeKayring usage
  * Fix some GPG bugs
  * Minor bugfixes
- updated to 0.14
  * Jingle audio / video chat
  * Improve Startup time
  * Copy emoticons, LaTeX expressions when they are selected
  * Fix status icon transparency by using gtk.statusicon
  * Groupchat auto-rejoin
  * geolocation (with geoclue)
  * use XDG standards
  * SCRAM-SHA-1 and SASL EXTERNAL authentication
  * MUC captcha
  * Lots of refactoring
- spec cleanup
* Sun May 16 2010 bernhard@bwalle.de
- update to 0.13.4
  * Fix some TLS connection
  * Don't raise a lot of "DB Error" dialog
  * Fix contact synchronisation
  * Add japanese translation
  * Minor fixes
  * Fix facebook xmpp server connection
  * Fix copy / paste with Ctrl+C on non-latin keyboard
  * Fix sending PEP information when connecting
  * Fix parsing HTML messages that have ascii markup
  * Fix some translations
  * Fix string comparison according to locales
  * Fix some gnomekeyring glitches
  * Copy emoticons when we copy / paste in conversations
- convert changelog to SUSE-style changes file
* Sat May 15 2010 pascal.bleser@opensuse.org
- update to 0.13.1:
  * adds BOSH connection
  * adds roster versioning
  * adds the ability to send contacts
  * adds a GUI to send XHTML messages
  * adds pubsub storage (for bookmarks)
* Sat May 15 2010 pascal.bleser@opensuse.org
- add patch to fix #4788: Error receiving OpenPGP encrypted messages with
  utf-8 characters
* Sat May 15 2010 pascal.bleser@opensuse.org
- update to 0.12.1:
  * fix filetransfer
  * updated german translation
  * fix click on notifications when text string is empty
  * improve systray popup menu
* Sat May 15 2010 pascal.bleser@opensuse.org
- license changed to GPL version 3
- scrapped old %%%%changelog entries
- moved to OBS
- update to 0.12:
  * support for End-To-End encryption and SSL certificate verification for security
  * support for transforming a one-to-one chat into a group chat
  * ability to minimize group chats in the roster for group chat management
  * single window mode
  * support for PEP (Personal Eventing Protocol)
  * support for Latex for the GUI
  * security improvements: Kerberos (GSSAPI) SASL Authentication mechanism
  * improve GUI of some windows
  * fix handling of invalid XML
  * fix freeze on connection
  * security improvements: End-to-End encryption, SSL certificate verification
  * ability to minimize groupchats in roster
  * block/Unblock contacts directly from roster
  * much faster contact list
* Sat May 15 2010 pascal.bleser@opensuse.org
- new upstream version
